@@ -91,7 +91,7 @@ class Excel:
             sheet_copied.title = sheet_name
 
         # copy existing sheets
-        writer.sheets = { ws.title:ws for ws in writer.book.worksheets }
+        # writer.sheets = { ws.title:ws for ws in writer.book.worksheets }
 
         if startrow is None:
             startrow = 0
@@ -103,7 +103,7 @@ class Excel:
         # TODO
 
         # write out the new sheet
-        df.to_excel(writer, sheet_name, startrow=startrow, header=header, **to_excel_kwargs)
+        df.to_excel(writer, sheet_name, startrow=startrow, header=header, if_sheet_exists='overlay', **to_excel_kwargs)
 
         # save the workbook
         writer.save()
